# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ROMIO.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ServerErrors_ice
import omero_Collections_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.romio
_M_omero.romio = Ice.openModule('omero.romio')
__name__ = 'omero.romio'
_M_omero.romio.__doc__ = """
Primitives for working with binary data.
"""

if '_t_RGBBands' not in _M_omero.romio.__dict__:
    _M_omero.romio._t_RGBBands = IcePy.defineSequence('::omero::romio::RGBBands', (), _M_Ice._t_ByteSeq)

_M_omero.romio.RedBand = 0

_M_omero.romio.GreenBand = 1

_M_omero.romio.BlueBand = 2

if 'RGBBuffer' not in _M_omero.romio.__dict__:
    _M_omero.romio.RGBBuffer = Ice.createTempClass()
    class RGBBuffer(Ice.Object):
        def __init__(self, bands=None, sizeX1=0, sizeX2=0):
            self.bands = bands
            self.sizeX1 = sizeX1
            self.sizeX2 = sizeX2

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::romio::RGBBuffer')

        def ice_id(self, current=None):
            return '::omero::romio::RGBBuffer'

        def ice_staticId():
            return '::omero::romio::RGBBuffer'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.romio._t_RGBBuffer)

        __repr__ = __str__

    _M_omero.romio.RGBBufferPrx = Ice.createTempClass()
    class RGBBufferPrx(Ice.ObjectPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.romio.RGBBufferPrx.ice_checkedCast(proxy, '::omero::romio::RGBBuffer', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.romio.RGBBufferPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::romio::RGBBuffer'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.romio._t_RGBBufferPrx = IcePy.defineProxy('::omero::romio::RGBBuffer', RGBBufferPrx)

    _M_omero.romio._t_RGBBuffer = IcePy.defineClass('::omero::romio::RGBBuffer', RGBBuffer, -1, (), False, False, None, (), (
        ('bands', (), _M_omero.romio._t_RGBBands, False, 0),
        ('sizeX1', (), IcePy._t_int, False, 0),
        ('sizeX2', (), IcePy._t_int, False, 0)
    ))
    RGBBuffer._ice_type = _M_omero.romio._t_RGBBuffer

    _M_omero.romio.RGBBuffer = RGBBuffer
    del RGBBuffer

    _M_omero.romio.RGBBufferPrx = RGBBufferPrx
    del RGBBufferPrx

if 'RegionDef' not in _M_omero.romio.__dict__:
    _M_omero.romio.RegionDef = Ice.createTempClass()
    class RegionDef(Ice.Object):
        def __init__(self, x=0, y=0, width=0, height=0):
            self.x = x
            self.y = y
            self.width = width
            self.height = height

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::romio::RegionDef')

        def ice_id(self, current=None):
            return '::omero::romio::RegionDef'

        def ice_staticId():
            return '::omero::romio::RegionDef'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.romio._t_RegionDef)

        __repr__ = __str__

    _M_omero.romio.RegionDefPrx = Ice.createTempClass()
    class RegionDefPrx(Ice.ObjectPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.romio.RegionDefPrx.ice_checkedCast(proxy, '::omero::romio::RegionDef', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.romio.RegionDefPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::romio::RegionDef'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.romio._t_RegionDefPrx = IcePy.defineProxy('::omero::romio::RegionDef', RegionDefPrx)

    _M_omero.romio._t_RegionDef = IcePy.defineClass('::omero::romio::RegionDef', RegionDef, -1, (), False, False, None, (), (
        ('x', (), IcePy._t_int, False, 0),
        ('y', (), IcePy._t_int, False, 0),
        ('width', (), IcePy._t_int, False, 0),
        ('height', (), IcePy._t_int, False, 0)
    ))
    RegionDef._ice_type = _M_omero.romio._t_RegionDef

    _M_omero.romio.RegionDef = RegionDef
    del RegionDef

    _M_omero.romio.RegionDefPrx = RegionDefPrx
    del RegionDefPrx

_M_omero.romio.XY = 0

_M_omero.romio.ZY = 1

_M_omero.romio.XZ = 2

if 'PlaneDef' not in _M_omero.romio.__dict__:
    _M_omero.romio.PlaneDef = Ice.createTempClass()
    class PlaneDef(Ice.Object):
        def __init__(self, slice=0, x=0, y=0, z=0, t=0, region=None, stride=0):
            self.slice = slice
            self.x = x
            self.y = y
            self.z = z
            self.t = t
            self.region = region
            self.stride = stride

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::romio::PlaneDef')

        def ice_id(self, current=None):
            return '::omero::romio::PlaneDef'

        def ice_staticId():
            return '::omero::romio::PlaneDef'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.romio._t_PlaneDef)

        __repr__ = __str__

    _M_omero.romio.PlaneDefPrx = Ice.createTempClass()
    class PlaneDefPrx(Ice.ObjectPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.romio.PlaneDefPrx.ice_checkedCast(proxy, '::omero::romio::PlaneDef', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.romio.PlaneDefPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::romio::PlaneDef'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.romio._t_PlaneDefPrx = IcePy.defineProxy('::omero::romio::PlaneDef', PlaneDefPrx)

    _M_omero.romio._t_PlaneDef = IcePy.declareClass('::omero::romio::PlaneDef')

    _M_omero.romio._t_PlaneDef = IcePy.defineClass('::omero::romio::PlaneDef', PlaneDef, -1, (), False, False, None, (), (
        ('slice', (), IcePy._t_int, False, 0),
        ('x', (), IcePy._t_int, False, 0),
        ('y', (), IcePy._t_int, False, 0),
        ('z', (), IcePy._t_int, False, 0),
        ('t', (), IcePy._t_int, False, 0),
        ('region', (), _M_omero.romio._t_RegionDef, False, 0),
        ('stride', (), IcePy._t_int, False, 0)
    ))
    PlaneDef._ice_type = _M_omero.romio._t_PlaneDef

    _M_omero.romio.PlaneDef = PlaneDef
    del PlaneDef

    _M_omero.romio.PlaneDefPrx = PlaneDefPrx
    del PlaneDefPrx

if 'PlaneDefWithMasks' not in _M_omero.romio.__dict__:
    _M_omero.romio.PlaneDefWithMasks = Ice.createTempClass()
    class PlaneDefWithMasks(_M_omero.romio.PlaneDef):
        """
        Extends PlaneDef by an option to toggle server side Mask rendering. By
        default all masks attached to the image fulfilling rendering criteria,
        will be rendered. This criteria is currently masks with a width and
        height equal to those of the image.
        Members:
        shapeIds -- Optional (currently unimplemented) list of Masks to render.
        """
        def __init__(self, slice=0, x=0, y=0, z=0, t=0, region=None, stride=0, shapeIds=None):
            _M_omero.romio.PlaneDef.__init__(self, slice, x, y, z, t, region, stride)
            self.shapeIds = shapeIds

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::romio::PlaneDef', '::omero::romio::PlaneDefWithMasks')

        def ice_id(self, current=None):
            return '::omero::romio::PlaneDefWithMasks'

        def ice_staticId():
            return '::omero::romio::PlaneDefWithMasks'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.romio._t_PlaneDefWithMasks)

        __repr__ = __str__

    _M_omero.romio.PlaneDefWithMasksPrx = Ice.createTempClass()
    class PlaneDefWithMasksPrx(_M_omero.romio.PlaneDefPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.romio.PlaneDefWithMasksPrx.ice_checkedCast(proxy, '::omero::romio::PlaneDefWithMasks', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.romio.PlaneDefWithMasksPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::romio::PlaneDefWithMasks'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.romio._t_PlaneDefWithMasksPrx = IcePy.defineProxy('::omero::romio::PlaneDefWithMasks', PlaneDefWithMasksPrx)

    _M_omero.romio._t_PlaneDefWithMasks = IcePy.declareClass('::omero::romio::PlaneDefWithMasks')

    _M_omero.romio._t_PlaneDefWithMasks = IcePy.defineClass('::omero::romio::PlaneDefWithMasks', PlaneDefWithMasks, -1, (), False, False, _M_omero.romio._t_PlaneDef, (), (('shapeIds', (), _M_omero.api._t_LongList, False, 0),))
    PlaneDefWithMasks._ice_type = _M_omero.romio._t_PlaneDefWithMasks

    _M_omero.romio.PlaneDefWithMasks = PlaneDefWithMasks
    del PlaneDefWithMasks

    _M_omero.romio.PlaneDefWithMasksPrx = PlaneDefWithMasksPrx
    del PlaneDefWithMasksPrx

if 'CodomainMapContext' not in _M_omero.romio.__dict__:
    _M_omero.romio.CodomainMapContext = Ice.createTempClass()
    class CodomainMapContext(Ice.Object):
        def __init__(self):
            pass

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::romio::CodomainMapContext')

        def ice_id(self, current=None):
            return '::omero::romio::CodomainMapContext'

        def ice_staticId():
            return '::omero::romio::CodomainMapContext'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.romio._t_CodomainMapContext)

        __repr__ = __str__

    _M_omero.romio.CodomainMapContextPrx = Ice.createTempClass()
    class CodomainMapContextPrx(Ice.ObjectPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.romio.CodomainMapContextPrx.ice_checkedCast(proxy, '::omero::romio::CodomainMapContext', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.romio.CodomainMapContextPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::romio::CodomainMapContext'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.romio._t_CodomainMapContextPrx = IcePy.defineProxy('::omero::romio::CodomainMapContext', CodomainMapContextPrx)

    _M_omero.romio._t_CodomainMapContext = IcePy.defineClass('::omero::romio::CodomainMapContext', CodomainMapContext, -1, (), False, False, None, (), ())
    CodomainMapContext._ice_type = _M_omero.romio._t_CodomainMapContext

    _M_omero.romio.CodomainMapContext = CodomainMapContext
    del CodomainMapContext

    _M_omero.romio.CodomainMapContextPrx = CodomainMapContextPrx
    del CodomainMapContextPrx

if 'ReverseIntensityMapContext' not in _M_omero.romio.__dict__:
    _M_omero.romio.ReverseIntensityMapContext = Ice.createTempClass()
    class ReverseIntensityMapContext(_M_omero.romio.CodomainMapContext):
        """
        The reverse intensity.
        """
        def __init__(self):
            _M_omero.romio.CodomainMapContext.__init__(self)

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::romio::CodomainMapContext', '::omero::romio::ReverseIntensityMapContext')

        def ice_id(self, current=None):
            return '::omero::romio::ReverseIntensityMapContext'

        def ice_staticId():
            return '::omero::romio::ReverseIntensityMapContext'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.romio._t_ReverseIntensityMapContext)

        __repr__ = __str__

    _M_omero.romio.ReverseIntensityMapContextPrx = Ice.createTempClass()
    class ReverseIntensityMapContextPrx(_M_omero.romio.CodomainMapContextPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.romio.ReverseIntensityMapContextPrx.ice_checkedCast(proxy, '::omero::romio::ReverseIntensityMapContext', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.romio.ReverseIntensityMapContextPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::romio::ReverseIntensityMapContext'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.romio._t_ReverseIntensityMapContextPrx = IcePy.defineProxy('::omero::romio::ReverseIntensityMapContext', ReverseIntensityMapContextPrx)

    _M_omero.romio._t_ReverseIntensityMapContext = IcePy.defineClass('::omero::romio::ReverseIntensityMapContext', ReverseIntensityMapContext, -1, (), False, False, _M_omero.romio._t_CodomainMapContext, (), ())
    ReverseIntensityMapContext._ice_type = _M_omero.romio._t_ReverseIntensityMapContext

    _M_omero.romio.ReverseIntensityMapContext = ReverseIntensityMapContext
    del ReverseIntensityMapContext

    _M_omero.romio.ReverseIntensityMapContextPrx = ReverseIntensityMapContextPrx
    del ReverseIntensityMapContextPrx

# End of module omero.romio

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ISession.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ModelF_ice
import omero_ServicesF_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')

# Start of module omero
__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'ISession' not in _M_omero.api.__dict__:
    _M_omero.api.ISession = Ice.createTempClass()
    class ISession(_M_omero.api.ServiceInterface):
        """
        omero.model.Session creation service for OMERO. Access to
        all other services is dependent upon a properly created and still
        active omero.model.Session.
        The session uuid ({@code omero.model.Session.getUuid}) can be
        considered a capability token, or temporary single use password.
        Simply by possessing it the client has access to all information
        available to the omero.model.Session.
        Note: Both the RMI ome.system.ServiceFactory as well
        as the Ice omero.api.ServiceFactory use
        omero.api.ISession to acquire a
        omero.model.Session. In the Ice case, Glacier2
        contacts omero.api.ISession itself and returns a
        ServiceFactory remote proxy. From both ServiceFactory
        instances, it is possible but not necessary to access
        omero.api.ISession.
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.ISession:
                raise RuntimeError('omero.api.ISession is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::ISession', '::omero::api::ServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::ISession'

        def ice_staticId():
            return '::omero::api::ISession'
        ice_staticId = staticmethod(ice_staticId)

        def createSession_async(self, _cb, p, credentials, current=None):
            """
            Creates a new session and returns it to the user.
            Arguments:
            _cb -- The asynchronous callback object.
            p -- 
            credentials -- 
            current -- The Current object for the invocation.
            Throws:
            ApiUsageException -- if principal is null
            SecurityViolation -- if the password check fails
            """
            pass

        def createUserSession_async(self, _cb, timeToLiveMilliseconds, timeToIdleMilliseconds, defaultGroup, current=None):
            """
            Allows a user to open up another session for him/herself with the given
            defaults without needing to re-enter password.
            Arguments:
            _cb -- The asynchronous callback object.
            timeToLiveMilliseconds -- 
            timeToIdleMilliseconds -- 
            defaultGroup -- 
            current -- The Current object for the invocation.
            """
            pass

        def createSessionWithTimeout_async(self, _cb, principal, timeToLiveMilliseconds, current=None):
            """
            Allows an admin to create a ome.model.meta.Session for the give
            omero.sys.Principal.
            Arguments:
            _cb -- The asynchronous callback object.
            principal -- Non-null omero.sys.Principal with the target user's name
            timeToLiveMilliseconds -- The time that this ome.model.meta.Session has until destruction. This is useful to override the server default so that an initial delay before the user is given the token will not be construed as idle time. A value less than 1 will cause the default max timeToLive to be used; but timeToIdle will be disabled.
            current -- The Current object for the invocation.
            """
            pass

        def createSessionWithTimeouts_async(self, _cb, principal, timeToLiveMilliseconds, timeToIdleMilliseconds, current=None):
            """
            Allows an admin to create a ome.model.meta.Session for
            the given omero.sys.Principal.
            Arguments:
            _cb -- The asynchronous callback object.
            principal -- Non-null omero.sys.Principal with the target user's name
            timeToLiveMilliseconds -- The time that this ome.model.meta.Session has until destruction. Setting the value to 0 will prevent destruction unless the session remains idle.
            timeToIdleMilliseconds -- The time that this ome.model.meta.Session can remain idle before being destroyed. Setting the value to 0 will prevent idleness based destruction.
            current -- The Current object for the invocation.
            """
            pass

        def getSession_async(self, _cb, sessionUuid, current=None):
            """
            Retrieves the session associated with this uuid, updating
            the last access time as well. Throws a
            omero.RemovedSessionException if not present, or
            a omero.SessionTimeoutException if expired.
            This method can be used as a ome.model.meta.Session ping.
            Arguments:
            _cb -- The asynchronous callback object.
            sessionUuid -- 
            current -- The Current object for the invocation.
            """
            pass

        def getReferenceCount_async(self, _cb, sessionUuid, current=None):
            """
            Retrieves the current reference count for the given uuid.
            Has the same semantics as {@code getSession}.
            Arguments:
            _cb -- The asynchronous callback object.
            sessionUuid -- 
            current -- The Current object for the invocation.
            """
            pass

        def closeSession_async(self, _cb, sess, current=None):
            """
            Closes session and releases all resources. It is preferred
            that all clients call this method as soon as possible to
            free memory, but it is possible to not call close, and
            rejoin a session later.
            The current reference count for the session is returned. If
            the session does not exist, -1. If this call caused the
            death of the session, then -2.
            Arguments:
            _cb -- The asynchronous callback object.
            sess -- 
            current -- The Current object for the invocation.
            """
            pass

        def getMyOpenSessions_async(self, _cb, current=None):
            """
            Returns a list of open sessions for the current user. The
            list is ordered by session creation time, so that the last
            item was created last.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def getMyOpenAgentSessions_async(self, _cb, agent, current=None):
            """
            Like {@code getMyOpenSessions} but returns only those
            sessions with the given agent string.
            Arguments:
            _cb -- The asynchronous callback object.
            agent -- 
            current -- The Current object for the invocation.
            """
            pass

        def getMyOpenClientSessions_async(self, _cb, current=None):
            """
            Like {@code getMyOpenSessions} but returns only those
            sessions started by official OMERO clients.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def getInput_async(self, _cb, sess, key, current=None):
            """
            Retrieves an entry from the given
            omero.model.Session input environment.
            Arguments:
            _cb -- The asynchronous callback object.
            sess -- 
            key -- 
            current -- The Current object for the invocation.
            """
            pass

        def getOutput_async(self, _cb, sess, key, current=None):
            """
            Retrieves an entry from the omero.model.Session
            output environment.
            Arguments:
            _cb -- The asynchronous callback object.
            sess -- 
            key -- 
            current -- The Current object for the invocation.
            """
            pass

        def setInput_async(self, _cb, sess, key, value, current=None):
            """
            Places an entry in the given omero.model.Session
            input environment.
            If the value is null, the key will be removed.
            Arguments:
            _cb -- The asynchronous callback object.
            sess -- 
            key -- 
            value -- 
            current -- The Current object for the invocation.
            """
            pass

        def setOutput_async(self, _cb, sess, key, value, current=None):
            """
            Places an entry in the given omero.model.Session
            output environment. If the value is null, the key will be
            removed.
            Arguments:
            _cb -- The asynchronous callback object.
            sess -- 
            key -- 
            value -- 
            current -- The Current object for the invocation.
            """
            pass

        def getInputKeys_async(self, _cb, sess, current=None):
            """
            Retrieves all keys in the omero.model.Session input
            environment.
            Arguments:
            _cb -- The asynchronous callback object.
            sess -- 
            current -- The Current object for the invocation.
            """
            pass

        def getOutputKeys_async(self, _cb, sess, current=None):
            """
            Retrieves all keys in the omero.model.Session
            output environment.
            Arguments:
            _cb -- The asynchronous callback object.
            sess -- 
            current -- The Current object for the invocation.
            """
            pass

        def getInputs_async(self, _cb, sess, current=None):
            """
            Retrieves all inputs from the given
            omero.model.Session input environment.
            Arguments:
            _cb -- The asynchronous callback object.
            sess -- 
            current -- The Current object for the invocation.
            """
            pass

        def getOutputs_async(self, _cb, sess, current=None):
            """
            Retrieves all outputs from the given
            omero.model.Session input environment.
            Arguments:
            _cb -- The asynchronous callback object.
            sess -- 
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_ISession)

        __repr__ = __str__

    _M_omero.api.ISessionPrx = Ice.createTempClass()
    class ISessionPrx(_M_omero.api.ServiceInterfacePrx):

        """
        Creates a new session and returns it to the user.
        Arguments:
        p -- 
        credentials -- 
        _ctx -- The request context for the invocation.
        Throws:
        ApiUsageException -- if principal is null
        SecurityViolation -- if the password check fails
        """
        def createSession(self, p, credentials, _ctx=None):
            return _M_omero.api.ISession._op_createSession.invoke(self, ((p, credentials), _ctx))

        """
        Creates a new session and returns it to the user.
        Arguments:
        p -- 
        credentials -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createSession(self, p, credentials, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_createSession.begin(self, ((p, credentials), _response, _ex, _sent, _ctx))

        """
        Creates a new session and returns it to the user.
        Arguments:
        p -- 
        credentials -- 
        Throws:
        ApiUsageException -- if principal is null
        SecurityViolation -- if the password check fails
        """
        def end_createSession(self, _r):
            return _M_omero.api.ISession._op_createSession.end(self, _r)

        """
        Allows a user to open up another session for him/herself with the given
        defaults without needing to re-enter password.
        Arguments:
        timeToLiveMilliseconds -- 
        timeToIdleMilliseconds -- 
        defaultGroup -- 
        _ctx -- The request context for the invocation.
        """
        def createUserSession(self, timeToLiveMilliseconds, timeToIdleMilliseconds, defaultGroup, _ctx=None):
            return _M_omero.api.ISession._op_createUserSession.invoke(self, ((timeToLiveMilliseconds, timeToIdleMilliseconds, defaultGroup), _ctx))

        """
        Allows a user to open up another session for him/herself with the given
        defaults without needing to re-enter password.
        Arguments:
        timeToLiveMilliseconds -- 
        timeToIdleMilliseconds -- 
        defaultGroup -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createUserSession(self, timeToLiveMilliseconds, timeToIdleMilliseconds, defaultGroup, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_createUserSession.begin(self, ((timeToLiveMilliseconds, timeToIdleMilliseconds, defaultGroup), _response, _ex, _sent, _ctx))

        """
        Allows a user to open up another session for him/herself with the given
        defaults without needing to re-enter password.
        Arguments:
        timeToLiveMilliseconds -- 
        timeToIdleMilliseconds -- 
        defaultGroup -- 
        """
        def end_createUserSession(self, _r):
            return _M_omero.api.ISession._op_createUserSession.end(self, _r)

        """
        Allows an admin to create a ome.model.meta.Session for the give
        omero.sys.Principal.
        Arguments:
        principal -- Non-null omero.sys.Principal with the target user's name
        timeToLiveMilliseconds -- The time that this ome.model.meta.Session has until destruction. This is useful to override the server default so that an initial delay before the user is given the token will not be construed as idle time. A value less than 1 will cause the default max timeToLive to be used; but timeToIdle will be disabled.
        _ctx -- The request context for the invocation.
        """
        def createSessionWithTimeout(self, principal, timeToLiveMilliseconds, _ctx=None):
            return _M_omero.api.ISession._op_createSessionWithTimeout.invoke(self, ((principal, timeToLiveMilliseconds), _ctx))

        """
        Allows an admin to create a ome.model.meta.Session for the give
        omero.sys.Principal.
        Arguments:
        principal -- Non-null omero.sys.Principal with the target user's name
        timeToLiveMilliseconds -- The time that this ome.model.meta.Session has until destruction. This is useful to override the server default so that an initial delay before the user is given the token will not be construed as idle time. A value less than 1 will cause the default max timeToLive to be used; but timeToIdle will be disabled.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createSessionWithTimeout(self, principal, timeToLiveMilliseconds, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_createSessionWithTimeout.begin(self, ((principal, timeToLiveMilliseconds), _response, _ex, _sent, _ctx))

        """
        Allows an admin to create a ome.model.meta.Session for the give
        omero.sys.Principal.
        Arguments:
        principal -- Non-null omero.sys.Principal with the target user's name
        timeToLiveMilliseconds -- The time that this ome.model.meta.Session has until destruction. This is useful to override the server default so that an initial delay before the user is given the token will not be construed as idle time. A value less than 1 will cause the default max timeToLive to be used; but timeToIdle will be disabled.
        """
        def end_createSessionWithTimeout(self, _r):
            return _M_omero.api.ISession._op_createSessionWithTimeout.end(self, _r)

        """
        Allows an admin to create a ome.model.meta.Session for
        the given omero.sys.Principal.
        Arguments:
        principal -- Non-null omero.sys.Principal with the target user's name
        timeToLiveMilliseconds -- The time that this ome.model.meta.Session has until destruction. Setting the value to 0 will prevent destruction unless the session remains idle.
        timeToIdleMilliseconds -- The time that this ome.model.meta.Session can remain idle before being destroyed. Setting the value to 0 will prevent idleness based destruction.
        _ctx -- The request context for the invocation.
        """
        def createSessionWithTimeouts(self, principal, timeToLiveMilliseconds, timeToIdleMilliseconds, _ctx=None):
            return _M_omero.api.ISession._op_createSessionWithTimeouts.invoke(self, ((principal, timeToLiveMilliseconds, timeToIdleMilliseconds), _ctx))

        """
        Allows an admin to create a ome.model.meta.Session for
        the given omero.sys.Principal.
        Arguments:
        principal -- Non-null omero.sys.Principal with the target user's name
        timeToLiveMilliseconds -- The time that this ome.model.meta.Session has until destruction. Setting the value to 0 will prevent destruction unless the session remains idle.
        timeToIdleMilliseconds -- The time that this ome.model.meta.Session can remain idle before being destroyed. Setting the value to 0 will prevent idleness based destruction.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createSessionWithTimeouts(self, principal, timeToLiveMilliseconds, timeToIdleMilliseconds, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_createSessionWithTimeouts.begin(self, ((principal, timeToLiveMilliseconds, timeToIdleMilliseconds), _response, _ex, _sent, _ctx))

        """
        Allows an admin to create a ome.model.meta.Session for
        the given omero.sys.Principal.
        Arguments:
        principal -- Non-null omero.sys.Principal with the target user's name
        timeToLiveMilliseconds -- The time that this ome.model.meta.Session has until destruction. Setting the value to 0 will prevent destruction unless the session remains idle.
        timeToIdleMilliseconds -- The time that this ome.model.meta.Session can remain idle before being destroyed. Setting the value to 0 will prevent idleness based destruction.
        """
        def end_createSessionWithTimeouts(self, _r):
            return _M_omero.api.ISession._op_createSessionWithTimeouts.end(self, _r)

        """
        Retrieves the session associated with this uuid, updating
        the last access time as well. Throws a
        omero.RemovedSessionException if not present, or
        a omero.SessionTimeoutException if expired.
        This method can be used as a ome.model.meta.Session ping.
        Arguments:
        sessionUuid -- 
        _ctx -- The request context for the invocation.
        """
        def getSession(self, sessionUuid, _ctx=None):
            return _M_omero.api.ISession._op_getSession.invoke(self, ((sessionUuid, ), _ctx))

        """
        Retrieves the session associated with this uuid, updating
        the last access time as well. Throws a
        omero.RemovedSessionException if not present, or
        a omero.SessionTimeoutException if expired.
        This method can be used as a ome.model.meta.Session ping.
        Arguments:
        sessionUuid -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getSession(self, sessionUuid, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getSession.begin(self, ((sessionUuid, ), _response, _ex, _sent, _ctx))

        """
        Retrieves the session associated with this uuid, updating
        the last access time as well. Throws a
        omero.RemovedSessionException if not present, or
        a omero.SessionTimeoutException if expired.
        This method can be used as a ome.model.meta.Session ping.
        Arguments:
        sessionUuid -- 
        """
        def end_getSession(self, _r):
            return _M_omero.api.ISession._op_getSession.end(self, _r)

        """
        Retrieves the current reference count for the given uuid.
        Has the same semantics as {@code getSession}.
        Arguments:
        sessionUuid -- 
        _ctx -- The request context for the invocation.
        """
        def getReferenceCount(self, sessionUuid, _ctx=None):
            return _M_omero.api.ISession._op_getReferenceCount.invoke(self, ((sessionUuid, ), _ctx))

        """
        Retrieves the current reference count for the given uuid.
        Has the same semantics as {@code getSession}.
        Arguments:
        sessionUuid -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getReferenceCount(self, sessionUuid, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getReferenceCount.begin(self, ((sessionUuid, ), _response, _ex, _sent, _ctx))

        """
        Retrieves the current reference count for the given uuid.
        Has the same semantics as {@code getSession}.
        Arguments:
        sessionUuid -- 
        """
        def end_getReferenceCount(self, _r):
            return _M_omero.api.ISession._op_getReferenceCount.end(self, _r)

        """
        Closes session and releases all resources. It is preferred
        that all clients call this method as soon as possible to
        free memory, but it is possible to not call close, and
        rejoin a session later.
        The current reference count for the session is returned. If
        the session does not exist, -1. If this call caused the
        death of the session, then -2.
        Arguments:
        sess -- 
        _ctx -- The request context for the invocation.
        """
        def closeSession(self, sess, _ctx=None):
            return _M_omero.api.ISession._op_closeSession.invoke(self, ((sess, ), _ctx))

        """
        Closes session and releases all resources. It is preferred
        that all clients call this method as soon as possible to
        free memory, but it is possible to not call close, and
        rejoin a session later.
        The current reference count for the session is returned. If
        the session does not exist, -1. If this call caused the
        death of the session, then -2.
        Arguments:
        sess -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_closeSession(self, sess, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_closeSession.begin(self, ((sess, ), _response, _ex, _sent, _ctx))

        """
        Closes session and releases all resources. It is preferred
        that all clients call this method as soon as possible to
        free memory, but it is possible to not call close, and
        rejoin a session later.
        The current reference count for the session is returned. If
        the session does not exist, -1. If this call caused the
        death of the session, then -2.
        Arguments:
        sess -- 
        """
        def end_closeSession(self, _r):
            return _M_omero.api.ISession._op_closeSession.end(self, _r)

        """
        Returns a list of open sessions for the current user. The
        list is ordered by session creation time, so that the last
        item was created last.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def getMyOpenSessions(self, _ctx=None):
            return _M_omero.api.ISession._op_getMyOpenSessions.invoke(self, ((), _ctx))

        """
        Returns a list of open sessions for the current user. The
        list is ordered by session creation time, so that the last
        item was created last.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getMyOpenSessions(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getMyOpenSessions.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns a list of open sessions for the current user. The
        list is ordered by session creation time, so that the last
        item was created last.
        Arguments:
        """
        def end_getMyOpenSessions(self, _r):
            return _M_omero.api.ISession._op_getMyOpenSessions.end(self, _r)

        """
        Like {@code getMyOpenSessions} but returns only those
        sessions with the given agent string.
        Arguments:
        agent -- 
        _ctx -- The request context for the invocation.
        """
        def getMyOpenAgentSessions(self, agent, _ctx=None):
            return _M_omero.api.ISession._op_getMyOpenAgentSessions.invoke(self, ((agent, ), _ctx))

        """
        Like {@code getMyOpenSessions} but returns only those
        sessions with the given agent string.
        Arguments:
        agent -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getMyOpenAgentSessions(self, agent, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getMyOpenAgentSessions.begin(self, ((agent, ), _response, _ex, _sent, _ctx))

        """
        Like {@code getMyOpenSessions} but returns only those
        sessions with the given agent string.
        Arguments:
        agent -- 
        """
        def end_getMyOpenAgentSessions(self, _r):
            return _M_omero.api.ISession._op_getMyOpenAgentSessions.end(self, _r)

        """
        Like {@code getMyOpenSessions} but returns only those
        sessions started by official OMERO clients.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def getMyOpenClientSessions(self, _ctx=None):
            return _M_omero.api.ISession._op_getMyOpenClientSessions.invoke(self, ((), _ctx))

        """
        Like {@code getMyOpenSessions} but returns only those
        sessions started by official OMERO clients.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getMyOpenClientSessions(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getMyOpenClientSessions.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Like {@code getMyOpenSessions} but returns only those
        sessions started by official OMERO clients.
        Arguments:
        """
        def end_getMyOpenClientSessions(self, _r):
            return _M_omero.api.ISession._op_getMyOpenClientSessions.end(self, _r)

        """
        Retrieves an entry from the given
        omero.model.Session input environment.
        Arguments:
        sess -- 
        key -- 
        _ctx -- The request context for the invocation.
        """
        def getInput(self, sess, key, _ctx=None):
            return _M_omero.api.ISession._op_getInput.invoke(self, ((sess, key), _ctx))

        """
        Retrieves an entry from the given
        omero.model.Session input environment.
        Arguments:
        sess -- 
        key -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getInput(self, sess, key, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getInput.begin(self, ((sess, key), _response, _ex, _sent, _ctx))

        """
        Retrieves an entry from the given
        omero.model.Session input environment.
        Arguments:
        sess -- 
        key -- 
        """
        def end_getInput(self, _r):
            return _M_omero.api.ISession._op_getInput.end(self, _r)

        """
        Retrieves an entry from the omero.model.Session
        output environment.
        Arguments:
        sess -- 
        key -- 
        _ctx -- The request context for the invocation.
        """
        def getOutput(self, sess, key, _ctx=None):
            return _M_omero.api.ISession._op_getOutput.invoke(self, ((sess, key), _ctx))

        """
        Retrieves an entry from the omero.model.Session
        output environment.
        Arguments:
        sess -- 
        key -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getOutput(self, sess, key, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getOutput.begin(self, ((sess, key), _response, _ex, _sent, _ctx))

        """
        Retrieves an entry from the omero.model.Session
        output environment.
        Arguments:
        sess -- 
        key -- 
        """
        def end_getOutput(self, _r):
            return _M_omero.api.ISession._op_getOutput.end(self, _r)

        """
        Places an entry in the given omero.model.Session
        input environment.
        If the value is null, the key will be removed.
        Arguments:
        sess -- 
        key -- 
        value -- 
        _ctx -- The request context for the invocation.
        """
        def setInput(self, sess, key, value, _ctx=None):
            return _M_omero.api.ISession._op_setInput.invoke(self, ((sess, key, value), _ctx))

        """
        Places an entry in the given omero.model.Session
        input environment.
        If the value is null, the key will be removed.
        Arguments:
        sess -- 
        key -- 
        value -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setInput(self, sess, key, value, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_setInput.begin(self, ((sess, key, value), _response, _ex, _sent, _ctx))

        """
        Places an entry in the given omero.model.Session
        input environment.
        If the value is null, the key will be removed.
        Arguments:
        sess -- 
        key -- 
        value -- 
        """
        def end_setInput(self, _r):
            return _M_omero.api.ISession._op_setInput.end(self, _r)

        """
        Places an entry in the given omero.model.Session
        output environment. If the value is null, the key will be
        removed.
        Arguments:
        sess -- 
        key -- 
        value -- 
        _ctx -- The request context for the invocation.
        """
        def setOutput(self, sess, key, value, _ctx=None):
            return _M_omero.api.ISession._op_setOutput.invoke(self, ((sess, key, value), _ctx))

        """
        Places an entry in the given omero.model.Session
        output environment. If the value is null, the key will be
        removed.
        Arguments:
        sess -- 
        key -- 
        value -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setOutput(self, sess, key, value, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_setOutput.begin(self, ((sess, key, value), _response, _ex, _sent, _ctx))

        """
        Places an entry in the given omero.model.Session
        output environment. If the value is null, the key will be
        removed.
        Arguments:
        sess -- 
        key -- 
        value -- 
        """
        def end_setOutput(self, _r):
            return _M_omero.api.ISession._op_setOutput.end(self, _r)

        """
        Retrieves all keys in the omero.model.Session input
        environment.
        Arguments:
        sess -- 
        _ctx -- The request context for the invocation.
        Returns: a java.util.Set of keys
        """
        def getInputKeys(self, sess, _ctx=None):
            return _M_omero.api.ISession._op_getInputKeys.invoke(self, ((sess, ), _ctx))

        """
        Retrieves all keys in the omero.model.Session input
        environment.
        Arguments:
        sess -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getInputKeys(self, sess, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getInputKeys.begin(self, ((sess, ), _response, _ex, _sent, _ctx))

        """
        Retrieves all keys in the omero.model.Session input
        environment.
        Arguments:
        sess -- 
        Returns: a java.util.Set of keys
        """
        def end_getInputKeys(self, _r):
            return _M_omero.api.ISession._op_getInputKeys.end(self, _r)

        """
        Retrieves all keys in the omero.model.Session
        output environment.
        Arguments:
        sess -- 
        _ctx -- The request context for the invocation.
        """
        def getOutputKeys(self, sess, _ctx=None):
            return _M_omero.api.ISession._op_getOutputKeys.invoke(self, ((sess, ), _ctx))

        """
        Retrieves all keys in the omero.model.Session
        output environment.
        Arguments:
        sess -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getOutputKeys(self, sess, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getOutputKeys.begin(self, ((sess, ), _response, _ex, _sent, _ctx))

        """
        Retrieves all keys in the omero.model.Session
        output environment.
        Arguments:
        sess -- 
        """
        def end_getOutputKeys(self, _r):
            return _M_omero.api.ISession._op_getOutputKeys.end(self, _r)

        """
        Retrieves all inputs from the given
        omero.model.Session input environment.
        Arguments:
        sess -- 
        _ctx -- The request context for the invocation.
        """
        def getInputs(self, sess, _ctx=None):
            return _M_omero.api.ISession._op_getInputs.invoke(self, ((sess, ), _ctx))

        """
        Retrieves all inputs from the given
        omero.model.Session input environment.
        Arguments:
        sess -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getInputs(self, sess, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getInputs.begin(self, ((sess, ), _response, _ex, _sent, _ctx))

        """
        Retrieves all inputs from the given
        omero.model.Session input environment.
        Arguments:
        sess -- 
        """
        def end_getInputs(self, _r):
            return _M_omero.api.ISession._op_getInputs.end(self, _r)

        """
        Retrieves all outputs from the given
        omero.model.Session input environment.
        Arguments:
        sess -- 
        _ctx -- The request context for the invocation.
        """
        def getOutputs(self, sess, _ctx=None):
            return _M_omero.api.ISession._op_getOutputs.invoke(self, ((sess, ), _ctx))

        """
        Retrieves all outputs from the given
        omero.model.Session input environment.
        Arguments:
        sess -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getOutputs(self, sess, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ISession._op_getOutputs.begin(self, ((sess, ), _response, _ex, _sent, _ctx))

        """
        Retrieves all outputs from the given
        omero.model.Session input environment.
        Arguments:
        sess -- 
        """
        def end_getOutputs(self, _r):
            return _M_omero.api.ISession._op_getOutputs.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.ISessionPrx.ice_checkedCast(proxy, '::omero::api::ISession', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.ISessionPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::ISession'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_ISessionPrx = IcePy.defineProxy('::omero::api::ISession', ISessionPrx)

    _M_omero.api._t_ISession = IcePy.defineClass('::omero::api::ISession', ISession, -1, (), True, False, None, (_M_omero.api._t_ServiceInterface,), ())
    ISession._ice_type = _M_omero.api._t_ISession

    ISession._op_createSession = IcePy.Operation('createSession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.sys._t_Principal, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_omero.model._t_Session, False, 0), (_M_omero._t_ServerError, _M_Glacier2._t_CannotCreateSessionException))
    ISession._op_createUserSession = IcePy.Operation('createUserSession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0), ((), IcePy._t_long, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_omero.model._t_Session, False, 0), (_M_omero._t_ServerError, _M_Glacier2._t_CannotCreateSessionException))
    ISession._op_createSessionWithTimeout = IcePy.Operation('createSessionWithTimeout', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.sys._t_Principal, False, 0), ((), IcePy._t_long, False, 0)), (), ((), _M_omero.model._t_Session, False, 0), (_M_omero._t_ServerError, _M_Glacier2._t_CannotCreateSessionException))
    ISession._op_createSessionWithTimeouts = IcePy.Operation('createSessionWithTimeouts', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.sys._t_Principal, False, 0), ((), IcePy._t_long, False, 0), ((), IcePy._t_long, False, 0)), (), ((), _M_omero.model._t_Session, False, 0), (_M_omero._t_ServerError, _M_Glacier2._t_CannotCreateSessionException))
    ISession._op_getSession = IcePy.Operation('getSession', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero.model._t_Session, False, 0), (_M_omero._t_ServerError,))
    ISession._op_getReferenceCount = IcePy.Operation('getReferenceCount', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), IcePy._t_int, False, 0), (_M_omero._t_ServerError,))
    ISession._op_closeSession = IcePy.Operation('closeSession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.model._t_Session, False, 0),), (), ((), IcePy._t_int, False, 0), (_M_omero._t_ServerError,))
    ISession._op_getMyOpenSessions = IcePy.Operation('getMyOpenSessions', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), _M_omero.api._t_SessionList, False, 0), (_M_omero._t_ServerError,))
    ISession._op_getMyOpenAgentSessions = IcePy.Operation('getMyOpenAgentSessions', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero.api._t_SessionList, False, 0), (_M_omero._t_ServerError,))
    ISession._op_getMyOpenClientSessions = IcePy.Operation('getMyOpenClientSessions', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), _M_omero.api._t_SessionList, False, 0), (_M_omero._t_ServerError,))
    ISession._op_getInput = IcePy.Operation('getInput', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_omero._t_RType, False, 0), (_M_omero._t_ServerError,))
    ISession._op_getOutput = IcePy.Operation('getOutput', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_omero._t_RType, False, 0), (_M_omero._t_ServerError,))
    ISession._op_setInput = IcePy.Operation('setInput', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0), ((), _M_omero._t_RType, False, 0)), (), None, (_M_omero._t_ServerError,))
    ISession._op_setOutput = IcePy.Operation('setOutput', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0), ((), _M_omero._t_RType, False, 0)), (), None, (_M_omero._t_ServerError,))
    ISession._op_getInputKeys = IcePy.Operation('getInputKeys', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero.api._t_StringSet, False, 0), (_M_omero._t_ServerError,))
    ISession._op_getOutputKeys = IcePy.Operation('getOutputKeys', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero.api._t_StringSet, False, 0), (_M_omero._t_ServerError,))
    ISession._op_getInputs = IcePy.Operation('getInputs', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero._t_RTypeDict, False, 0), (_M_omero._t_ServerError,))
    ISession._op_getOutputs = IcePy.Operation('getOutputs', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero._t_RTypeDict, False, 0), (_M_omero._t_ServerError,))

    _M_omero.api.ISession = ISession
    del ISession

    _M_omero.api.ISessionPrx = ISessionPrx
    del ISessionPrx

# End of module omero.api

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Detector.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'ElectricPotential' not in _M_omero.model.__dict__:
    _M_omero.model._t_ElectricPotential = IcePy.declareClass('::omero::model::ElectricPotential')
    _M_omero.model._t_ElectricPotentialPrx = IcePy.declareProxy('::omero::model::ElectricPotential')

if 'DetectorType' not in _M_omero.model.__dict__:
    _M_omero.model._t_DetectorType = IcePy.declareClass('::omero::model::DetectorType')
    _M_omero.model._t_DetectorTypePrx = IcePy.declareProxy('::omero::model::DetectorType')

if 'Instrument' not in _M_omero.model.__dict__:
    _M_omero.model._t_Instrument = IcePy.declareClass('::omero::model::Instrument')
    _M_omero.model._t_InstrumentPrx = IcePy.declareProxy('::omero::model::Instrument')

if 'DetectorAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_DetectorAnnotationLink = IcePy.declareClass('::omero::model::DetectorAnnotationLink')
    _M_omero.model._t_DetectorAnnotationLinkPrx = IcePy.declareProxy('::omero::model::DetectorAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_DetectorAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_DetectorAnnotationLinksSeq = IcePy.defineSequence('::omero::model::DetectorAnnotationLinksSeq', (), _M_omero.model._t_DetectorAnnotationLink)

if '_t_DetectorLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_DetectorLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::DetectorLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Detector' not in _M_omero.model.__dict__:
    _M_omero.model.Detector = Ice.createTempClass()
    class Detector(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _manufacturer=None, _model=None, _lotNumber=None, _serialNumber=None, _voltage=None, _gain=None, _offsetValue=None, _zoom=None, _amplificationGain=None, _type=None, _instrument=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None):
            if Ice.getType(self) == _M_omero.model.Detector:
                raise RuntimeError('omero.model.Detector is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._manufacturer = _manufacturer
            self._model = _model
            self._lotNumber = _lotNumber
            self._serialNumber = _serialNumber
            self._voltage = _voltage
            self._gain = _gain
            self._offsetValue = _offsetValue
            self._zoom = _zoom
            self._amplificationGain = _amplificationGain
            self._type = _type
            self._instrument = _instrument
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Detector', '::omero::model::IObject')

        def ice_id(self, current=None):
            return '::omero::model::Detector'

        def ice_staticId():
            return '::omero::model::Detector'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getManufacturer(self, current=None):
            pass

        def setManufacturer(self, theManufacturer, current=None):
            pass

        def getModel(self, current=None):
            pass

        def setModel(self, theModel, current=None):
            pass

        def getLotNumber(self, current=None):
            pass

        def setLotNumber(self, theLotNumber, current=None):
            pass

        def getSerialNumber(self, current=None):
            pass

        def setSerialNumber(self, theSerialNumber, current=None):
            pass

        def getVoltage(self, current=None):
            pass

        def setVoltage(self, theVoltage, current=None):
            pass

        def getGain(self, current=None):
            pass

        def setGain(self, theGain, current=None):
            pass

        def getOffsetValue(self, current=None):
            pass

        def setOffsetValue(self, theOffsetValue, current=None):
            pass

        def getZoom(self, current=None):
            pass

        def setZoom(self, theZoom, current=None):
            pass

        def getAmplificationGain(self, current=None):
            pass

        def setAmplificationGain(self, theAmplificationGain, current=None):
            pass

        def getType(self, current=None):
            pass

        def setType(self, theType, current=None):
            pass

        def getInstrument(self, current=None):
            pass

        def setInstrument(self, theInstrument, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addDetectorAnnotationLink(self, target, current=None):
            pass

        def addAllDetectorAnnotationLinkSet(self, targets, current=None):
            pass

        def removeDetectorAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllDetectorAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addDetectorAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findDetectorAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeDetectorAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Detector)

        __repr__ = __str__

    _M_omero.model.DetectorPrx = Ice.createTempClass()
    class DetectorPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Detector._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Detector._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Detector._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Detector._op_setVersion.end(self, _r)

        def getManufacturer(self, _ctx=None):
            return _M_omero.model.Detector._op_getManufacturer.invoke(self, ((), _ctx))

        def begin_getManufacturer(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getManufacturer.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getManufacturer(self, _r):
            return _M_omero.model.Detector._op_getManufacturer.end(self, _r)

        def setManufacturer(self, theManufacturer, _ctx=None):
            return _M_omero.model.Detector._op_setManufacturer.invoke(self, ((theManufacturer, ), _ctx))

        def begin_setManufacturer(self, theManufacturer, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setManufacturer.begin(self, ((theManufacturer, ), _response, _ex, _sent, _ctx))

        def end_setManufacturer(self, _r):
            return _M_omero.model.Detector._op_setManufacturer.end(self, _r)

        def getModel(self, _ctx=None):
            return _M_omero.model.Detector._op_getModel.invoke(self, ((), _ctx))

        def begin_getModel(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getModel.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getModel(self, _r):
            return _M_omero.model.Detector._op_getModel.end(self, _r)

        def setModel(self, theModel, _ctx=None):
            return _M_omero.model.Detector._op_setModel.invoke(self, ((theModel, ), _ctx))

        def begin_setModel(self, theModel, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setModel.begin(self, ((theModel, ), _response, _ex, _sent, _ctx))

        def end_setModel(self, _r):
            return _M_omero.model.Detector._op_setModel.end(self, _r)

        def getLotNumber(self, _ctx=None):
            return _M_omero.model.Detector._op_getLotNumber.invoke(self, ((), _ctx))

        def begin_getLotNumber(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getLotNumber.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLotNumber(self, _r):
            return _M_omero.model.Detector._op_getLotNumber.end(self, _r)

        def setLotNumber(self, theLotNumber, _ctx=None):
            return _M_omero.model.Detector._op_setLotNumber.invoke(self, ((theLotNumber, ), _ctx))

        def begin_setLotNumber(self, theLotNumber, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setLotNumber.begin(self, ((theLotNumber, ), _response, _ex, _sent, _ctx))

        def end_setLotNumber(self, _r):
            return _M_omero.model.Detector._op_setLotNumber.end(self, _r)

        def getSerialNumber(self, _ctx=None):
            return _M_omero.model.Detector._op_getSerialNumber.invoke(self, ((), _ctx))

        def begin_getSerialNumber(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getSerialNumber.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSerialNumber(self, _r):
            return _M_omero.model.Detector._op_getSerialNumber.end(self, _r)

        def setSerialNumber(self, theSerialNumber, _ctx=None):
            return _M_omero.model.Detector._op_setSerialNumber.invoke(self, ((theSerialNumber, ), _ctx))

        def begin_setSerialNumber(self, theSerialNumber, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setSerialNumber.begin(self, ((theSerialNumber, ), _response, _ex, _sent, _ctx))

        def end_setSerialNumber(self, _r):
            return _M_omero.model.Detector._op_setSerialNumber.end(self, _r)

        def getVoltage(self, _ctx=None):
            return _M_omero.model.Detector._op_getVoltage.invoke(self, ((), _ctx))

        def begin_getVoltage(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getVoltage.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVoltage(self, _r):
            return _M_omero.model.Detector._op_getVoltage.end(self, _r)

        def setVoltage(self, theVoltage, _ctx=None):
            return _M_omero.model.Detector._op_setVoltage.invoke(self, ((theVoltage, ), _ctx))

        def begin_setVoltage(self, theVoltage, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setVoltage.begin(self, ((theVoltage, ), _response, _ex, _sent, _ctx))

        def end_setVoltage(self, _r):
            return _M_omero.model.Detector._op_setVoltage.end(self, _r)

        def getGain(self, _ctx=None):
            return _M_omero.model.Detector._op_getGain.invoke(self, ((), _ctx))

        def begin_getGain(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getGain.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getGain(self, _r):
            return _M_omero.model.Detector._op_getGain.end(self, _r)

        def setGain(self, theGain, _ctx=None):
            return _M_omero.model.Detector._op_setGain.invoke(self, ((theGain, ), _ctx))

        def begin_setGain(self, theGain, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setGain.begin(self, ((theGain, ), _response, _ex, _sent, _ctx))

        def end_setGain(self, _r):
            return _M_omero.model.Detector._op_setGain.end(self, _r)

        def getOffsetValue(self, _ctx=None):
            return _M_omero.model.Detector._op_getOffsetValue.invoke(self, ((), _ctx))

        def begin_getOffsetValue(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getOffsetValue.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getOffsetValue(self, _r):
            return _M_omero.model.Detector._op_getOffsetValue.end(self, _r)

        def setOffsetValue(self, theOffsetValue, _ctx=None):
            return _M_omero.model.Detector._op_setOffsetValue.invoke(self, ((theOffsetValue, ), _ctx))

        def begin_setOffsetValue(self, theOffsetValue, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setOffsetValue.begin(self, ((theOffsetValue, ), _response, _ex, _sent, _ctx))

        def end_setOffsetValue(self, _r):
            return _M_omero.model.Detector._op_setOffsetValue.end(self, _r)

        def getZoom(self, _ctx=None):
            return _M_omero.model.Detector._op_getZoom.invoke(self, ((), _ctx))

        def begin_getZoom(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getZoom.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getZoom(self, _r):
            return _M_omero.model.Detector._op_getZoom.end(self, _r)

        def setZoom(self, theZoom, _ctx=None):
            return _M_omero.model.Detector._op_setZoom.invoke(self, ((theZoom, ), _ctx))

        def begin_setZoom(self, theZoom, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setZoom.begin(self, ((theZoom, ), _response, _ex, _sent, _ctx))

        def end_setZoom(self, _r):
            return _M_omero.model.Detector._op_setZoom.end(self, _r)

        def getAmplificationGain(self, _ctx=None):
            return _M_omero.model.Detector._op_getAmplificationGain.invoke(self, ((), _ctx))

        def begin_getAmplificationGain(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getAmplificationGain.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAmplificationGain(self, _r):
            return _M_omero.model.Detector._op_getAmplificationGain.end(self, _r)

        def setAmplificationGain(self, theAmplificationGain, _ctx=None):
            return _M_omero.model.Detector._op_setAmplificationGain.invoke(self, ((theAmplificationGain, ), _ctx))

        def begin_setAmplificationGain(self, theAmplificationGain, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setAmplificationGain.begin(self, ((theAmplificationGain, ), _response, _ex, _sent, _ctx))

        def end_setAmplificationGain(self, _r):
            return _M_omero.model.Detector._op_setAmplificationGain.end(self, _r)

        def getType(self, _ctx=None):
            return _M_omero.model.Detector._op_getType.invoke(self, ((), _ctx))

        def begin_getType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getType(self, _r):
            return _M_omero.model.Detector._op_getType.end(self, _r)

        def setType(self, theType, _ctx=None):
            return _M_omero.model.Detector._op_setType.invoke(self, ((theType, ), _ctx))

        def begin_setType(self, theType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setType.begin(self, ((theType, ), _response, _ex, _sent, _ctx))

        def end_setType(self, _r):
            return _M_omero.model.Detector._op_setType.end(self, _r)

        def getInstrument(self, _ctx=None):
            return _M_omero.model.Detector._op_getInstrument.invoke(self, ((), _ctx))

        def begin_getInstrument(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getInstrument.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getInstrument(self, _r):
            return _M_omero.model.Detector._op_getInstrument.end(self, _r)

        def setInstrument(self, theInstrument, _ctx=None):
            return _M_omero.model.Detector._op_setInstrument.invoke(self, ((theInstrument, ), _ctx))

        def begin_setInstrument(self, theInstrument, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_setInstrument.begin(self, ((theInstrument, ), _response, _ex, _sent, _ctx))

        def end_setInstrument(self, _r):
            return _M_omero.model.Detector._op_setInstrument.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Detector._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Detector._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Detector._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Detector._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Detector._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Detector._op_copyAnnotationLinks.end(self, _r)

        def addDetectorAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Detector._op_addDetectorAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addDetectorAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_addDetectorAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addDetectorAnnotationLink(self, _r):
            return _M_omero.model.Detector._op_addDetectorAnnotationLink.end(self, _r)

        def addAllDetectorAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Detector._op_addAllDetectorAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllDetectorAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_addAllDetectorAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllDetectorAnnotationLinkSet(self, _r):
            return _M_omero.model.Detector._op_addAllDetectorAnnotationLinkSet.end(self, _r)

        def removeDetectorAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Detector._op_removeDetectorAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeDetectorAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_removeDetectorAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeDetectorAnnotationLink(self, _r):
            return _M_omero.model.Detector._op_removeDetectorAnnotationLink.end(self, _r)

        def removeAllDetectorAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Detector._op_removeAllDetectorAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllDetectorAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_removeAllDetectorAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllDetectorAnnotationLinkSet(self, _r):
            return _M_omero.model.Detector._op_removeAllDetectorAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Detector._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Detector._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Detector._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Detector._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Detector._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Detector._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Detector._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Detector._op_linkAnnotation.end(self, _r)

        def addDetectorAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Detector._op_addDetectorAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addDetectorAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_addDetectorAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addDetectorAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Detector._op_addDetectorAnnotationLinkToBoth.end(self, _r)

        def findDetectorAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Detector._op_findDetectorAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findDetectorAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_findDetectorAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findDetectorAnnotationLink(self, _r):
            return _M_omero.model.Detector._op_findDetectorAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Detector._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Detector._op_unlinkAnnotation.end(self, _r)

        def removeDetectorAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Detector._op_removeDetectorAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeDetectorAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_removeDetectorAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeDetectorAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Detector._op_removeDetectorAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Detector._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Detector._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Detector._op_linkedAnnotationList.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.DetectorPrx.ice_checkedCast(proxy, '::omero::model::Detector', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.DetectorPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Detector'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_DetectorPrx = IcePy.defineProxy('::omero::model::Detector', DetectorPrx)

    _M_omero.model._t_Detector = IcePy.declareClass('::omero::model::Detector')

    _M_omero.model._t_Detector = IcePy.defineClass('::omero::model::Detector', Detector, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_manufacturer', (), _M_omero._t_RString, False, 0),
        ('_model', (), _M_omero._t_RString, False, 0),
        ('_lotNumber', (), _M_omero._t_RString, False, 0),
        ('_serialNumber', (), _M_omero._t_RString, False, 0),
        ('_voltage', (), _M_omero.model._t_ElectricPotential, False, 0),
        ('_gain', (), _M_omero._t_RDouble, False, 0),
        ('_offsetValue', (), _M_omero._t_RDouble, False, 0),
        ('_zoom', (), _M_omero._t_RDouble, False, 0),
        ('_amplificationGain', (), _M_omero._t_RDouble, False, 0),
        ('_type', (), _M_omero.model._t_DetectorType, False, 0),
        ('_instrument', (), _M_omero.model._t_Instrument, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_DetectorAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0)
    ))
    Detector._ice_type = _M_omero.model._t_Detector

    Detector._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Detector._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Detector._op_getManufacturer = IcePy.Operation('getManufacturer', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Detector._op_setManufacturer = IcePy.Operation('setManufacturer', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Detector._op_getModel = IcePy.Operation('getModel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Detector._op_setModel = IcePy.Operation('setModel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Detector._op_getLotNumber = IcePy.Operation('getLotNumber', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Detector._op_setLotNumber = IcePy.Operation('setLotNumber', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Detector._op_getSerialNumber = IcePy.Operation('getSerialNumber', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Detector._op_setSerialNumber = IcePy.Operation('setSerialNumber', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Detector._op_getVoltage = IcePy.Operation('getVoltage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ElectricPotential, False, 0), ())
    Detector._op_setVoltage = IcePy.Operation('setVoltage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ElectricPotential, False, 0),), (), None, ())
    Detector._op_getGain = IcePy.Operation('getGain', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Detector._op_setGain = IcePy.Operation('setGain', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Detector._op_getOffsetValue = IcePy.Operation('getOffsetValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Detector._op_setOffsetValue = IcePy.Operation('setOffsetValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Detector._op_getZoom = IcePy.Operation('getZoom', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Detector._op_setZoom = IcePy.Operation('setZoom', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Detector._op_getAmplificationGain = IcePy.Operation('getAmplificationGain', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Detector._op_setAmplificationGain = IcePy.Operation('setAmplificationGain', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Detector._op_getType = IcePy.Operation('getType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_DetectorType, False, 0), ())
    Detector._op_setType = IcePy.Operation('setType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_DetectorType, False, 0),), (), None, ())
    Detector._op_getInstrument = IcePy.Operation('getInstrument', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Instrument, False, 0), ())
    Detector._op_setInstrument = IcePy.Operation('setInstrument', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Instrument, False, 0),), (), None, ())
    Detector._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Detector._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Detector._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_DetectorAnnotationLinksSeq, False, 0), ())
    Detector._op_addDetectorAnnotationLink = IcePy.Operation('addDetectorAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_DetectorAnnotationLink, False, 0),), (), None, ())
    Detector._op_addAllDetectorAnnotationLinkSet = IcePy.Operation('addAllDetectorAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_DetectorAnnotationLinksSeq, False, 0),), (), None, ())
    Detector._op_removeDetectorAnnotationLink = IcePy.Operation('removeDetectorAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_DetectorAnnotationLink, False, 0),), (), None, ())
    Detector._op_removeAllDetectorAnnotationLinkSet = IcePy.Operation('removeAllDetectorAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_DetectorAnnotationLinksSeq, False, 0),), (), None, ())
    Detector._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Detector._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Detector, False, 0),), (), None, ())
    Detector._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Detector._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_DetectorAnnotationLink, False, 0), ())
    Detector._op_addDetectorAnnotationLinkToBoth = IcePy.Operation('addDetectorAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_DetectorAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Detector._op_findDetectorAnnotationLink = IcePy.Operation('findDetectorAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_DetectorAnnotationLinksSeq, False, 0), ())
    Detector._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Detector._op_removeDetectorAnnotationLinkFromBoth = IcePy.Operation('removeDetectorAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_DetectorAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Detector._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_DetectorLinkedAnnotationSeq, False, 0), ())

    _M_omero.model.Detector = Detector
    del Detector

    _M_omero.model.DetectorPrx = DetectorPrx
    del DetectorPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `IRepositoryInfo.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ModelF_ice
import omero_ServicesF_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')

# Start of module omero
__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'IRepositoryInfo' not in _M_omero.api.__dict__:
    _M_omero.api.IRepositoryInfo = Ice.createTempClass()
    class IRepositoryInfo(_M_omero.api.ServiceInterface):
        """
        Provides methods for obtaining information for server repository
        disk space allocation. Could be used generically to obtain usage
        information for any mount point, however, this interface is
        prepared for the API to provide methods to obtain usage info for
        the server filesystem containing the image uploads. For the OMERO
        server base this is /OMERO. For this implementation it could be
        anything e.g. /Data1.
        Methods that fail or cannot execute on the server will throw an
        InternalException. This would not be normal and would indicate some
        server or disk failure.
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.IRepositoryInfo:
                raise RuntimeError('omero.api.IRepositoryInfo is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::IRepositoryInfo', '::omero::api::ServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::IRepositoryInfo'

        def ice_staticId():
            return '::omero::api::IRepositoryInfo'
        ice_staticId = staticmethod(ice_staticId)

        def getUsedSpaceInKilobytes_async(self, _cb, current=None):
            """
            Returns the total space in bytes for this file system
            including nested subdirectories.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            Throws:
            ResourceError -- If there is a problem retrieving disk space used.
            """
            pass

        def getFreeSpaceInKilobytes_async(self, _cb, current=None):
            """
            Returns the free or available space on this file system
            including nested subdirectories.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            Throws:
            ResourceError -- If there is a problem retrieving disk space free.
            """
            pass

        def getUsageFraction_async(self, _cb, current=None):
            """
            Returns a double of the used space divided by the free
            space.
            This method will be called by a client to watch the
            repository filesystem so that it doesn't exceed 95% full.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            Throws:
            ResourceError -- If there is a problem calculating the usage fraction.
            """
            pass

        def sanityCheckRepository_async(self, _cb, current=None):
            """
            Checks that image data repository has not exceeded 95% disk
            space use level.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            Throws:
            InternalException -- If there is a critical failure while sanity checking the repository.
            ResourceError -- If the repository usage has exceeded 95%.
            """
            pass

        def removeUnusedFiles_async(self, _cb, current=None):
            """
            Removes all files from the server that do not have an
            OriginalFile complement in the database, all the Pixels
            that do not have a complement in the database and all the
            Thumbnail's that do not have a complement in the database.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            Throws:
            ResourceError -- If deletion fails.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_IRepositoryInfo)

        __repr__ = __str__

    _M_omero.api.IRepositoryInfoPrx = Ice.createTempClass()
    class IRepositoryInfoPrx(_M_omero.api.ServiceInterfacePrx):

        """
        Returns the total space in bytes for this file system
        including nested subdirectories.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: Total space used on this file system.
        Throws:
        ResourceError -- If there is a problem retrieving disk space used.
        """
        def getUsedSpaceInKilobytes(self, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_getUsedSpaceInKilobytes.invoke(self, ((), _ctx))

        """
        Returns the total space in bytes for this file system
        including nested subdirectories.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getUsedSpaceInKilobytes(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_getUsedSpaceInKilobytes.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns the total space in bytes for this file system
        including nested subdirectories.
        Arguments:
        Returns: Total space used on this file system.
        Throws:
        ResourceError -- If there is a problem retrieving disk space used.
        """
        def end_getUsedSpaceInKilobytes(self, _r):
            return _M_omero.api.IRepositoryInfo._op_getUsedSpaceInKilobytes.end(self, _r)

        """
        Returns the free or available space on this file system
        including nested subdirectories.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: Free space on this file system in KB.
        Throws:
        ResourceError -- If there is a problem retrieving disk space free.
        """
        def getFreeSpaceInKilobytes(self, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_getFreeSpaceInKilobytes.invoke(self, ((), _ctx))

        """
        Returns the free or available space on this file system
        including nested subdirectories.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getFreeSpaceInKilobytes(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_getFreeSpaceInKilobytes.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns the free or available space on this file system
        including nested subdirectories.
        Arguments:
        Returns: Free space on this file system in KB.
        Throws:
        ResourceError -- If there is a problem retrieving disk space free.
        """
        def end_getFreeSpaceInKilobytes(self, _r):
            return _M_omero.api.IRepositoryInfo._op_getFreeSpaceInKilobytes.end(self, _r)

        """
        Returns a double of the used space divided by the free
        space.
        This method will be called by a client to watch the
        repository filesystem so that it doesn't exceed 95% full.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: Fraction of used/free.
        Throws:
        ResourceError -- If there is a problem calculating the usage fraction.
        """
        def getUsageFraction(self, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_getUsageFraction.invoke(self, ((), _ctx))

        """
        Returns a double of the used space divided by the free
        space.
        This method will be called by a client to watch the
        repository filesystem so that it doesn't exceed 95% full.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getUsageFraction(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_getUsageFraction.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns a double of the used space divided by the free
        space.
        This method will be called by a client to watch the
        repository filesystem so that it doesn't exceed 95% full.
        Arguments:
        Returns: Fraction of used/free.
        Throws:
        ResourceError -- If there is a problem calculating the usage fraction.
        """
        def end_getUsageFraction(self, _r):
            return _M_omero.api.IRepositoryInfo._op_getUsageFraction.end(self, _r)

        """
        Checks that image data repository has not exceeded 95% disk
        space use level.
        Arguments:
        _ctx -- The request context for the invocation.
        Throws:
        InternalException -- If there is a critical failure while sanity checking the repository.
        ResourceError -- If the repository usage has exceeded 95%.
        """
        def sanityCheckRepository(self, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_sanityCheckRepository.invoke(self, ((), _ctx))

        """
        Checks that image data repository has not exceeded 95% disk
        space use level.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_sanityCheckRepository(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_sanityCheckRepository.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Checks that image data repository has not exceeded 95% disk
        space use level.
        Arguments:
        Throws:
        InternalException -- If there is a critical failure while sanity checking the repository.
        ResourceError -- If the repository usage has exceeded 95%.
        """
        def end_sanityCheckRepository(self, _r):
            return _M_omero.api.IRepositoryInfo._op_sanityCheckRepository.end(self, _r)

        """
        Removes all files from the server that do not have an
        OriginalFile complement in the database, all the Pixels
        that do not have a complement in the database and all the
        Thumbnail's that do not have a complement in the database.
        Arguments:
        _ctx -- The request context for the invocation.
        Throws:
        ResourceError -- If deletion fails.
        """
        def removeUnusedFiles(self, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_removeUnusedFiles.invoke(self, ((), _ctx))

        """
        Removes all files from the server that do not have an
        OriginalFile complement in the database, all the Pixels
        that do not have a complement in the database and all the
        Thumbnail's that do not have a complement in the database.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_removeUnusedFiles(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRepositoryInfo._op_removeUnusedFiles.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Removes all files from the server that do not have an
        OriginalFile complement in the database, all the Pixels
        that do not have a complement in the database and all the
        Thumbnail's that do not have a complement in the database.
        Arguments:
        Throws:
        ResourceError -- If deletion fails.
        """
        def end_removeUnusedFiles(self, _r):
            return _M_omero.api.IRepositoryInfo._op_removeUnusedFiles.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.IRepositoryInfoPrx.ice_checkedCast(proxy, '::omero::api::IRepositoryInfo', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.IRepositoryInfoPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::IRepositoryInfo'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_IRepositoryInfoPrx = IcePy.defineProxy('::omero::api::IRepositoryInfo', IRepositoryInfoPrx)

    _M_omero.api._t_IRepositoryInfo = IcePy.defineClass('::omero::api::IRepositoryInfo', IRepositoryInfo, -1, (), True, False, None, (_M_omero.api._t_ServiceInterface,), ())
    IRepositoryInfo._ice_type = _M_omero.api._t_IRepositoryInfo

    IRepositoryInfo._op_getUsedSpaceInKilobytes = IcePy.Operation('getUsedSpaceInKilobytes', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), IcePy._t_long, False, 0), (_M_omero._t_ServerError,))
    IRepositoryInfo._op_getFreeSpaceInKilobytes = IcePy.Operation('getFreeSpaceInKilobytes', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), IcePy._t_long, False, 0), (_M_omero._t_ServerError,))
    IRepositoryInfo._op_getUsageFraction = IcePy.Operation('getUsageFraction', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), IcePy._t_double, False, 0), (_M_omero._t_ServerError,))
    IRepositoryInfo._op_sanityCheckRepository = IcePy.Operation('sanityCheckRepository', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (), (), None, (_M_omero._t_ServerError,))
    IRepositoryInfo._op_removeUnusedFiles = IcePy.Operation('removeUnusedFiles', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (), (), None, (_M_omero._t_ServerError,))

    _M_omero.api.IRepositoryInfo = IRepositoryInfo
    del IRepositoryInfo

    _M_omero.api.IRepositoryInfoPrx = IRepositoryInfoPrx
    del IRepositoryInfoPrx

# End of module omero.api

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Constants.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module omero
_M_omero = Ice.openModule('omero')
__name__ = 'omero'

# Start of module omero.constants
_M_omero.constants = Ice.openModule('omero.constants')
__name__ = 'omero.constants'
_M_omero.constants.__doc__ = """
Most client-intended constants are provided in this module.
"""

_M_omero.constants.CLIENTUUID = "omero.client.uuid"

_M_omero.constants.SESSIONUUID = "omero.session.uuid"

_M_omero.constants.GCINTERVAL = 60

_M_omero.constants.GLACIER2PORT = 4064

_M_omero.constants.MESSAGESIZEMAX = 250000

_M_omero.constants.DEFAULTBATCHSIZE = 2000

_M_omero.constants.DEFAULTBLOCKSIZE = 5000000

_M_omero.constants.CLIENTTHREADPOOLSIZE = 5

_M_omero.constants.CONNECTTIMEOUT = 5000

_M_omero.constants.DEFAULTROUTER = "OMERO.Glacier2/router:ssl -p \100omero.port\100 -h \100omero.host\100" if _version_info_[0] < 3 else "OMERO.Glacier2/router:ssl -p \U00000040omero.port\U00000040 -h \U00000040omero.host\U00000040"

_M_omero.constants.ACMCLIENTHEARTBEAT = 2

_M_omero.constants.ACMCLIENTTIMEOUT = 60000

_M_omero.constants.ADMINSERVICE = "omero.api.IAdmin"

_M_omero.constants.ANALYSISSERVICE = "omero.api.IAnalysis"

_M_omero.constants.CONFIGSERVICE = "omero.api.IConfig"

_M_omero.constants.CONTAINERSERVICE = "omero.api.IContainer"

_M_omero.constants.EXPORTERSERVICE = "omero.api.Exporter"

_M_omero.constants.LDAPSERVICE = "omero.api.ILdap"

_M_omero.constants.PIXELSSERVICE = "omero.api.IPixels"

_M_omero.constants.PROJECTIONSERVICE = "omero.api.IProjection"

_M_omero.constants.QUERYSERVICE = "omero.api.IQuery"

_M_omero.constants.SESSIONSERVICE = "omero.api.ISession"

_M_omero.constants.SHARESERVICE = "omero.api.IShare"

_M_omero.constants.TIMELINESERVICE = "omero.api.ITimeline"

_M_omero.constants.TYPESSERVICE = "omero.api.ITypes"

_M_omero.constants.UPDATESERVICE = "omero.api.IUpdate"

_M_omero.constants.JOBHANDLE = "omero.api.JobHandle"

_M_omero.constants.RAWFILESTORE = "omero.api.RawFileStore"

_M_omero.constants.RAWPIXELSSTORE = "omero.api.RawPixelsStore"

_M_omero.constants.RENDERINGENGINE = "omero.api.RenderingEngine"

_M_omero.constants.ROISERVICE = "omero.api.IRoi"

_M_omero.constants.SCRIPTSERVICE = "omero.api.IScript"

_M_omero.constants.SEARCH = "omero.api.Search"

_M_omero.constants.THUMBNAILSTORE = "omero.api.ThumbnailStore"

_M_omero.constants.REPOSITORYINFO = "omero.api.IRepositoryInfo"

_M_omero.constants.RENDERINGSETTINGS = "omero.api.IRenderingSettings"

_M_omero.constants.METADATASERVICE = "omero.api.IMetadata"

_M_omero.constants.SHAREDRESOURCES = "omero.grid.SharedResources"

_M_omero.constants.USERNAME = "omero.user"

_M_omero.constants.PASSWORD = "omero.pass"

_M_omero.constants.GROUP = "omero.group"

_M_omero.constants.EVENT = "omero.event"

_M_omero.constants.AGENT = "omero.agent"

_M_omero.constants.IP = "omero.ip"

# Start of module omero.constants.cluster
_M_omero.constants.cluster = Ice.openModule('omero.constants.cluster')
__name__ = 'omero.constants.cluster'

_M_omero.constants.cluster.REDIRECT = "omero.cluster.redirect"

# End of module omero.constants.cluster

__name__ = 'omero.constants'

# Start of module omero.constants.annotation
_M_omero.constants.annotation = Ice.openModule('omero.constants.annotation')
__name__ = 'omero.constants.annotation'
_M_omero.constants.annotation.__doc__ = """
General constants used for annotations.
"""

# Start of module omero.constants.annotation.file
_M_omero.constants.annotation.file = Ice.openModule('omero.constants.annotation.file')
__name__ = 'omero.constants.annotation.file'
_M_omero.constants.annotation.file.__doc__ = """
Constants used for file annotations.
"""

_M_omero.constants.annotation.file.ORIGINALMETADATAPREFIX = "/openmicroscopy.org/omero/image_files/"

_M_omero.constants.annotation.file.ORIGINALMETADATA = "original_metadata.txt"

# End of module omero.constants.annotation.file

__name__ = 'omero.constants.annotation'

# End of module omero.constants.annotation

__name__ = 'omero.constants'

# Start of module omero.constants.data
_M_omero.constants.data = Ice.openModule('omero.constants.data')
__name__ = 'omero.constants.data'
_M_omero.constants.data.__doc__ = """
Constants used for field defaults and similar
in the omero.model classes.
"""

_M_omero.constants.data.NONAMESET = "NO_NAME_SET"

# End of module omero.constants.data

__name__ = 'omero.constants'

if 'LogLevel' not in _M_omero.constants.__dict__:
    _M_omero.constants.LogLevel = Ice.createTempClass()
    class LogLevel(Ice.EnumBase):
        """
        Log levels used by {@code RawAccessRequest}'s {@code log} command for {@code path}.
        """

        def __init__(self, _n, _v):
            Ice.EnumBase.__init__(self, _n, _v)

        def valueOf(self, _n):
            if _n in self._enumerators:
                return self._enumerators[_n]
            return None
        valueOf = classmethod(valueOf)

    LogLevel.Trace = LogLevel("Trace", 0)
    LogLevel.Debug = LogLevel("Debug", 1)
    LogLevel.Info = LogLevel("Info", 2)
    LogLevel.Warn = LogLevel("Warn", 3)
    LogLevel.Error = LogLevel("Error", 4)
    LogLevel._enumerators = { 0:LogLevel.Trace, 1:LogLevel.Debug, 2:LogLevel.Info, 3:LogLevel.Warn, 4:LogLevel.Error }

    _M_omero.constants._t_LogLevel = IcePy.defineEnum('::omero::constants::LogLevel', LogLevel, (), LogLevel._enumerators)

    _M_omero.constants.LogLevel = LogLevel
    del LogLevel

# Start of module omero.constants.metadata
_M_omero.constants.metadata = Ice.openModule('omero.constants.metadata')
__name__ = 'omero.constants.metadata'
_M_omero.constants.metadata.__doc__ = """
Namespaces for the omero.api.IMetadata interface.
"""

_M_omero.constants.metadata.NSINSIGHTTAGSET = "openmicroscopy.org/omero/insight/tagset"

_M_omero.constants.metadata.NSINSIGHTRATING = "openmicroscopy.org/omero/insight/rating"

_M_omero.constants.metadata.NSMOVIE = "openmicroscopy.org/omero/movie"

_M_omero.constants.metadata.NSCLIENTMAPANNOTATION = "openmicroscopy.org/omero/client/mapAnnotation"

# End of module omero.constants.metadata

__name__ = 'omero.constants'

# Start of module omero.constants.namespaces
_M_omero.constants.namespaces = Ice.openModule('omero.constants.namespaces')
__name__ = 'omero.constants.namespaces'
_M_omero.constants.namespaces.__doc__ = """
General namespaces for StructuredAnnotations
"""

_M_omero.constants.namespaces.NSFSRENAME = "openmicroscopy.org/omero/fs/rename"

_M_omero.constants.namespaces.NSMEASUREMENT = "openmicroscopy.org/omero/measurement"

_M_omero.constants.namespaces.NSAUTOCLOSE = "openmicroscopy.org/omero/import/autoClose"

_M_omero.constants.namespaces.NSTARGETTEMPLATE = "openmicroscopy.org/omero/import/targetTemplate"

_M_omero.constants.namespaces.NSCOMPANIONFILE = "openmicroscopy.org/omero/import/companionFile"

_M_omero.constants.namespaces.NSLOGFILE = "openmicroscopy.org/omero/import/logFile"

_M_omero.constants.namespaces.NSFILETRANSFER = "openmicroscopy.org/omero/import/fileTransfer"

_M_omero.constants.namespaces.NSEXPERIMENTERPHOTO = "openmicroscopy.org/omero/experimenter/photo"

_M_omero.constants.namespaces.NSBULKANNOTATIONS = "openmicroscopy.org/omero/bulk_annotations"

_M_omero.constants.namespaces.NSOMETIFF = "openmicroscopy.org/omero/ome_tiff"

_M_omero.constants.namespaces.NSCREATED = "openmicroscopy.org/omero/scripts/results/created"

_M_omero.constants.namespaces.NSDOWNLOAD = "openmicroscopy.org/omero/scripts/results/download"

_M_omero.constants.namespaces.NSVIEW = "openmicroscopy.org/omero/scripts/results/view"

_M_omero.constants.namespaces.NSDYNAMIC = "openmicroscopy.org/omero/scripts/job/dynamic"

_M_omero.constants.namespaces.NSMODULO = "openmicroscopy.org/omero/dimension/modulo"

# End of module omero.constants.namespaces

__name__ = 'omero.constants'

# Start of module omero.constants.analysis
_M_omero.constants.analysis = Ice.openModule('omero.constants.analysis')
__name__ = 'omero.constants.analysis'
_M_omero.constants.analysis.__doc__ = """
Namespaces for analysis.
"""

# Start of module omero.constants.analysis.flim
_M_omero.constants.analysis.flim = Ice.openModule('omero.constants.analysis.flim')
__name__ = 'omero.constants.analysis.flim'
_M_omero.constants.analysis.flim.__doc__ = """
namespaces related to the FLIM analysis.
"""

_M_omero.constants.analysis.flim.NSFLIM = "openmicroscopy.org/omero/analysis/flim"

_M_omero.constants.analysis.flim.KEYWORDFLIMCELL = "Cell"

_M_omero.constants.analysis.flim.KEYWORDFLIMBACKGROUND = "Background"

# End of module omero.constants.analysis.flim

__name__ = 'omero.constants.analysis'

# End of module omero.constants.analysis

__name__ = 'omero.constants'

# Start of module omero.constants.jobs
_M_omero.constants.jobs = Ice.openModule('omero.constants.jobs')
__name__ = 'omero.constants.jobs'

_M_omero.constants.jobs.SUBMITTED = "Submitted"

_M_omero.constants.jobs.RESUBMITTED = "Resubmitted"

_M_omero.constants.jobs.QUEUED = "Queued"

_M_omero.constants.jobs.REQUEUED = "Requeued"

_M_omero.constants.jobs.RUNNING = "Running"

_M_omero.constants.jobs.ERRORX = "Error"

_M_omero.constants.jobs.WAITING = "Waiting"

_M_omero.constants.jobs.FINISHED = "Finished"

_M_omero.constants.jobs.CANCELLED = "Cancelled"

# End of module omero.constants.jobs

__name__ = 'omero.constants'

# Start of module omero.constants.permissions
_M_omero.constants.permissions = Ice.openModule('omero.constants.permissions')
__name__ = 'omero.constants.permissions'

_M_omero.constants.permissions.LINKRESTRICTION = 0

_M_omero.constants.permissions.EDITRESTRICTION = 1

_M_omero.constants.permissions.DELETERESTRICTION = 2

_M_omero.constants.permissions.ANNOTATERESTRICTION = 3

_M_omero.constants.permissions.CHGRPRESTRICTION = 4

_M_omero.constants.permissions.CHOWNRESTRICTION = 5

_M_omero.constants.permissions.BINARYACCESS = "RESTRICT-BINARY-ACCESS"

# End of module omero.constants.permissions

__name__ = 'omero.constants'

# Start of module omero.constants.projection
_M_omero.constants.projection = Ice.openModule('omero.constants.projection')
__name__ = 'omero.constants.projection'

_M_omero.constants.projection.MAXIMUMINTENSITYMETHODOLOGY = "MAXIMUM_INTENSITY_PROJECTION"

_M_omero.constants.projection.MEANINTENSITYMETHODOLOGY = "MEAN_INTENSITY_PROJECTION"

_M_omero.constants.projection.SUMINTENSITYMETHODOLOGY = "SUM_INTENSITY_PROJECTION"

if 'ProjectionType' not in _M_omero.constants.projection.__dict__:
    _M_omero.constants.projection.ProjectionType = Ice.createTempClass()
    class ProjectionType(Ice.EnumBase):
        """
        Used by the IProjection methods to declare which projection to perform.
        """

        def __init__(self, _n, _v):
            Ice.EnumBase.__init__(self, _n, _v)

        def valueOf(self, _n):
            if _n in self._enumerators:
                return self._enumerators[_n]
            return None
        valueOf = classmethod(valueOf)

    ProjectionType.MAXIMUMINTENSITY = ProjectionType("MAXIMUMINTENSITY", 0)
    ProjectionType.MEANINTENSITY = ProjectionType("MEANINTENSITY", 1)
    ProjectionType.SUMINTENSITY = ProjectionType("SUMINTENSITY", 2)
    ProjectionType._enumerators = { 0:ProjectionType.MAXIMUMINTENSITY, 1:ProjectionType.MEANINTENSITY, 2:ProjectionType.SUMINTENSITY }

    _M_omero.constants.projection._t_ProjectionType = IcePy.defineEnum('::omero::constants::projection::ProjectionType', ProjectionType, (), ProjectionType._enumerators)

    _M_omero.constants.projection.ProjectionType = ProjectionType
    del ProjectionType

# End of module omero.constants.projection

__name__ = 'omero.constants'

# Start of module omero.constants.topics
_M_omero.constants.topics = Ice.openModule('omero.constants.topics')
__name__ = 'omero.constants.topics'

_M_omero.constants.topics.PROCESSORACCEPTS = "/internal/ProcessorAccept"

_M_omero.constants.topics.HEARTBEAT = "/public/HeartBeat"

# End of module omero.constants.topics

__name__ = 'omero.constants'

# Start of module omero.constants.categories
_M_omero.constants.categories = Ice.openModule('omero.constants.categories')
__name__ = 'omero.constants.categories'

_M_omero.constants.categories.PROCESSORCALLBACK = "ProcessorCallback"

_M_omero.constants.categories.PROCESSCALLBACK = "ProcessCallback"

# End of module omero.constants.categories

__name__ = 'omero.constants'

# End of module omero.constants

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright 2007 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt
#
"""
Used to be generated by blitz/templates/resources/combined.vm
"""
import omero.constants.permissions as ocp

import Ice
import IceImport
IceImport.load("omero_model_Permissions_ice")
_omero = Ice.openModule("omero")
_omero_model = Ice.openModule("omero.model")
__name__ = "omero.model"

"""Permissions class which implements Unix-like rw logic for user/group/world.

>>> p = PermissionsI()
object #0 (::omero::model::Permissions)
{
    perm1 = -35
}
"""


class PermissionsI(_omero_model.Permissions):

    def __init__(self, l=None):
        super(PermissionsI, self).__init__()
        self.__immutable = False
        self._restrictions = None
        if isinstance(l, str):
            self._perm1 = -1
            self.from_string(l)
        elif l is not None:
            self._perm1 = int(l)
        else:
            self._perm1 = -1

    def granted(self, mask, shift):
        return (self._perm1 & (mask << shift)) == (mask << shift)

    def set(self, mask, shift, on):
        self.throwIfImmutable()
        if on:
            self._perm1 = (self._perm1 | (0 | (mask << shift)))
        else:
            self._perm1 = (self._perm1 & (-1 ^ (mask << shift)))

    # shift 8; mask 4
    def isUserRead(self):
        return self.granted(4, 8)

    def setUserRead(self, value):
        self.set(4, 8, value)

    # shift 8; mask 2
    def isUserWrite(self):
        return self.granted(2, 8)

    def setUserWrite(self, value):
        self.set(2, 8, value)

    # shift 8; mask 1
    def isUserAnnotate(self):
        return self.granted(1, 8)

    def setUserAnnotate(self, value):
        self.set(1, 8, value)

    # shift 4; mask 4
    def isGroupRead(self):
        return self.granted(4, 4)

    def setGroupRead(self, value):
        self.set(4, 4, value)

    # shift 4; mask 2
    def isGroupWrite(self):
        return self.granted(2, 4)

    def setGroupWrite(self, value):
        self.set(2, 4, value)

    # shift 4; mask 1
    def isGroupAnnotate(self):
        return self.granted(1, 4)

    def setGroupAnnotate(self, value):
        self.set(1, 4, value)

    # shift 0; mask 4
    def isWorldRead(self):
        return self.granted(4, 0)

    def setWorldRead(self, value):
        self.set(4, 0, value)

    # shift 0; mask 2
    def isWorldWrite(self):
        return self.granted(2, 0)

    def setWorldWrite(self, value):
        self.set(2, 0, value)

    # shift 0; mask 1
    def isWorldAnnotate(self):
        return self.granted(1, 0)

    def setWorldAnnotate(self, value):
        self.set(1, 0, value)

    # Calculated values

    def isRestricted(self, restriction, current=None):
        rs = self._extendedRestrictions
        if rs is not None:
            return restriction in rs
        return False

    def isDisallow(self, restriction, current=None):
        rs = self._restrictions
        if rs is not None and len(rs) > restriction:
            return rs[restriction]
        return False

    def canAnnotate(self, current=None):
        return not self.isDisallow(ocp.ANNOTATERESTRICTION)

    def canDelete(self, current=None):
        return not self.isDisallow(ocp.DELETERESTRICTION)

    def canEdit(self, current=None):
        return not self.isDisallow(ocp.EDITRESTRICTION)

    def canLink(self, current=None):
        return not self.isDisallow(ocp.LINKRESTRICTION)

    def canChgrp(self, current=None):
        return not self.isDisallow(ocp.CHGRPRESTRICTION)

    def canChown(self, current=None):
        return not self.isDisallow(ocp.CHOWNRESTRICTION)

    # Accessors; do not use

    def getPerm1(self):
        return self._perm1

    def setPerm1(self, _perm1):
        self.throwIfImmutable()
        self._perm1 = _perm1
        pass

    def from_string(self, perms):
        """
        Sets the state of this instance via the 'perms' string.
        Returns 'self'. Also used by the constructor which
        takes a string.
        """
        import re
        base = r"([rR\-_])([aAwW\-_])"
        regex = re.compile(r"^(L?)%s$" % (base*3))
        match = regex.match(perms)
        if match is None:
            raise ValueError("Invalid permission string: %s" % perms)
        ur = match.group(2)
        uw = match.group(3)
        gr = match.group(4)
        gw = match.group(5)
        wr = match.group(6)
        ww = match.group(7)
        # User
        self.setUserRead(ur.lower() == "r")
        self.setUserAnnotate(uw.lower() == "a")
        if uw.lower() == "w":
            self.setUserAnnotate(True)  # w implies a
            self.setUserWrite(True)
        else:
            self.setUserWrite(False)
        # Group
        self.setGroupRead(gr.lower() == "r")
        self.setGroupAnnotate(gw.lower() == "a")
        if gw.lower() == "w":
            self.setGroupAnnotate(True)  # w implies a
            self.setGroupWrite(True)
        else:
            self.setGroupWrite(False)
        # World
        self.setWorldRead(wr.lower() == "r")
        self.setWorldAnnotate(ww.lower() == "a")
        if ww.lower() == "w":
            self.setWorldAnnotate(True)  # w implies a
            self.setWorldWrite(True)
        else:
            self.setWorldWrite(False)

        return self

    def __str__(self):
        vals = []
        # User
        vals.append(self.isUserRead() and "r" or "-")
        if self.isUserWrite():
            vals.append("w")
        elif self.isUserAnnotate():
            vals.append("a")
        else:
            vals.append("-")
        # Group
        vals.append(self.isGroupRead() and "r" or "-")
        if self.isGroupWrite():
            vals.append("w")
        elif self.isGroupAnnotate():
            vals.append("a")
        else:
            vals.append("-")
        # World
        vals.append(self.isWorldRead() and "r" or "-")
        if self.isWorldWrite():
            vals.append("w")
        elif self.isWorldAnnotate():
            vals.append("a")
        else:
            vals.append("-")
        return "".join(vals)

    def throwIfImmutable(self):
        """
        Check the __immutable field and throw a ClientError
        if it's true.
        """
        if self.__immutable:
            raise _omero.ClientError("ImmutablePermissions: %s" %
                                     self.__str__())

    def ice_postUnmarshal(self):
        """
        Provides additional initialization once all data loaded
        Required due to __getattr__ implementation.
        """
        # _omero_model.Permissions.ice_postUnmarshal(self)
        self.__immutable = True

    def ice_preMarshal(self):
        """
        Provides additional validation before data is sent
        Required due to __getattr__ implementation.
        """
        pass  # Currently unused

    def __getattr__(self, attr):
        if attr == "perm1":
            return self.getPerm1()
        else:
            raise AttributeError(attr)

    def __setattr__(self, attr, value):
        if attr.startswith("_"):
            self.__dict__[attr] = value
        else:
            try:
                object.__getattribute__(self, attr)
                object.__setattr__(self, attr, value)
            except AttributeError:
                if attr == "perm1":
                    return self.setPerm1(value)
                else:
                    raise

_omero_model.PermissionsI = PermissionsI


def _test():
    import doctest
    doctest.testmod()

if __name__ == "__main__":
    _test()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#
#   Copyright 2010-2014 Glencoe Software, Inc. All rights reserved.
#   Use is subject to license terms supplied in LICENSE.txt
#

# This file is an import-only file providing a mechanism for other files to
# import a range of modules in a controlled way. It could be made to pass
# flake8 but given its simplicity it is being marked as noqa for now.
#
# flake8: noqa

import Ice
import IceImport
import omero
if omero.__import_style__ is None:
    omero.__import_style__ = "all"
    import omero.min
    import omero.callbacks
    import omero.ObjectFactoryRegistrar
    IceImport.load("omero_FS_ice")
    IceImport.load("omero_System_ice")
    IceImport.load("omero_Collections_ice")
    IceImport.load("omero_Repositories_ice")
    IceImport.load("omero_SharedResources_ice")
    IceImport.load("omero_Scripts_ice")
    IceImport.load("omero_Tables_ice")
    IceImport.load("omero_api_IAdmin_ice")
    IceImport.load("omero_api_IConfig_ice")
    IceImport.load("omero_api_IContainer_ice")
    IceImport.load("omero_api_ILdap_ice")
    IceImport.load("omero_api_IMetadata_ice")
    IceImport.load("omero_api_IPixels_ice")
    IceImport.load("omero_api_IProjection_ice")
    IceImport.load("omero_api_IQuery_ice")
    IceImport.load("omero_api_IRenderingSettings_ice")
    IceImport.load("omero_api_IRepositoryInfo_ice")
    IceImport.load("omero_api_IRoi_ice")
    IceImport.load("omero_api_IScript_ice")
    IceImport.load("omero_api_ISession_ice")
    IceImport.load("omero_api_IShare_ice")
    IceImport.load("omero_api_ITimeline_ice")
    IceImport.load("omero_api_ITypes_ice")
    IceImport.load("omero_api_IUpdate_ice")
    IceImport.load("omero_api_Exporter_ice")
    IceImport.load("omero_api_JobHandle_ice")
    IceImport.load("omero_api_MetadataStore_ice")
    IceImport.load("omero_api_RawFileStore_ice")
    IceImport.load("omero_api_RawPixelsStore_ice")
    IceImport.load("omero_api_RenderingEngine_ice")
    IceImport.load("omero_api_Search_ice")
    IceImport.load("omero_api_ThumbnailStore_ice")
    IceImport.load("omero_cmd_Admin_ice")
    IceImport.load("omero_cmd_API_ice")
    IceImport.load("omero_cmd_Basic_ice")
    IceImport.load("omero_cmd_FS_ice")
    IceImport.load("omero_cmd_Graphs_ice")
    IceImport.load("omero_cmd_Mail_ice")
    IceImport.load("omero_model_Units_ice")
    import omero_sys_ParametersI
    import omero_model_PermissionsI
